@@ -24,29 +24,24 @@ namespace fdb5 {
 
 class TypeIgnore : public Type {
 
-public: // methods
+public:  // methods
 
-    TypeIgnore(const std::string &name, const std::string &type);
+    TypeIgnore(const std::string& name, const std::string& type);
 
-    virtual ~TypeIgnore();
+    ~TypeIgnore() override;
 
-    virtual void getValues(const metkit::mars::MarsRequest &request,
-                           const std::string &keyword,
-                           eckit::StringList &values,
-                           const Notifier &wind,
-                           const DB *db) const;
+    virtual void getValues(const metkit::mars::MarsRequest& request, const std::string& keyword,
+                           eckit::StringList& values, const Notifier& wind, const CatalogueReader* cat) const override;
 
-    virtual void toKey(std::ostream &out,
-                       const std::string &keyword,
-                       const std::string &value) const;
-private: // methods
+    std::string toKey(const std::string& value) const override;
 
-    virtual void print( std::ostream &out ) const;
+private:  // methods
 
+    void print(std::ostream& out) const override;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
 
 #endif
